@@ -8,7 +8,6 @@
 #' several generations, is associated to an effect inherited from a treatment
 #' and that stochastic effect can be dismissed.
 #'
-#' @docType package
 #'
 #' @name methylInheritance-package
 #'
@@ -22,16 +21,19 @@
 #' Astrid Deschenes <adeschen@hotmail.com>
 #'
 #' @seealso
-#' \itemize{
-#'     \item \code{\link{runPermutation}} {for running a
+#' \describe{
+#'     \item{\code{\link{runPermutation}}}{ for running a
 #'     permutation analysis, and optionally an observation analysis, on a
 #'     specified multi-generational dataset}
-#'     \item \code{\link{runObservation}} {for running an
+#'     \item{\code{\link{runObservation}}}{ for running an
 #'     observation analysis on a specified multi-generational dataset}
 #' }
 #'
+#' @return methylInheritance
+#' @encoding UTF-8
 #' @keywords package
-NULL
+#' @keywords internal
+"_PACKAGE"
 
 #' All samples information, formated by \code{methylKit}, in a
 #' \code{methylRawList} format (for demo purpose).
@@ -64,8 +66,8 @@ NULL
 #' (6 controls and 6 cases) in each generation.
 #'
 #' @seealso
-#' \itemize{
-#'     \item \code{\link{runPermutation}} {for running a
+#' \describe{
+#'     \item{\code{\link{runPermutation}}}{ for running a
 #'     permutation analysis, and optionally an observation analysis, using
 #'     multi-generational dataset}
 #' }
@@ -117,11 +119,11 @@ NULL
 #' (6 controls and 6 cases) in each generation.
 #'
 #' @seealso
-#' \itemize{
-#'     \item \code{\link{runPermutation}} {for running a
+#' \describe{
+#'     \item{\code{\link{runPermutation}}}{ for running a
 #'     permutation analysis, and optionally an observation analysis,
-#'     using multi-generational dataset}
-#'     \item \code{\link{runObservation}} {for running an
+#'     using a multi-generational dataset}
+#'     \item{\code{\link{runObservation}}}{ for running an
 #'     observation analysis using methylKit info entry}
 #' }
 #'
@@ -425,8 +427,8 @@ NULL
 #' }
 #'
 #' @seealso
-#' \itemize{
-#'     \item \code{\link{extractInfo}} {for extracting the
+#' \describe{
+#'     \item{\code{\link{extractInfo}}}{ for extracting the
 #'     information specific to a subsection of the permutation analysis}
 #' }
 #'
